import cv2
import numpy as np
import matplotlib.pyplot as plt
#
def segment_image(num_segments,image_path=path):
    # Read the image using OpenCV
    image = cv2.imread(image_path)

    # Convert the image from BGR to RGB (OpenCV uses BGR by default)
    image_rgb = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)

    # Reshape the image to a 2D array of pixels (rows represent pixels, columns represent color channels)
    pixels = image_rgb.reshape(-1, 3).astype(np.float32)

    # Perform k-means clustering on the pixels
    criteria = (cv2.TERM_CRITERIA_EPS + cv2.TERM_CRITERIA_MAX_ITER, 100, 0.2)
    _, labels, centers = cv2.kmeans(pixels, num_segments, None, criteria, 10, cv2.KMEANS_RANDOM_CENTERS)

    # Convert the centers back to 8-bit integers (RGB color values)
    centers = np.uint8(centers)

    # Map the labels to the center values to get the segmented image
    segmented_image = centers[labels.flatten()]
    segmented_image = segmented_image.reshape(image_rgb.shape)

    return segmented_image

def Imgsegment(path_to_image):
    # Replace 'path_to_image' with the actual path to your image file


    # Define the number of segments for k-means clustering
    num_segments = int(input("Enter number of segments"))  # You can adjust this value based on your requirement

    # Perform image segmentation using k-means clustering
    segmented_image = segment_image(num_segments,path_to_image)

    # Display the original and segmented images using matplotlib
    plt.figure(figsize=(10, 5))

    plt.subplot(1, 2, 1)
    plt.imshow(cv2.imread(path_to_image))
    plt.title('Original Image')
    plt.axis('off')

    plt.subplot(1, 2, 2)
    plt.imshow(segmented_image)
    plt.title('Segmented Image (K = {})'.format(num_segments))
    plt.axis('off')

    plt.show()


